Stan Math Library: stan::math::common_type< Eigen::Matrix< T1, R, C >, Eigen::Matrix< T2, R, C > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::common_type< Eigen::Matrix< T1, R, C >, Eigen::Matrix< T2, R, C > > Struct Template Reference

`#include <common_type.hpp>`

## Public Types
typedef Eigen::Matrix< typename common_type< T1, T2 >::type, R, C > | type

## Detailed Description

### template<typename T1, typename T2, int R, int C>
struct stan::math::common_type< Eigen::Matrix< T1, R, C >, Eigen::Matrix< T2, R, C > >

Definition at line 23 of file common_type.hpp.

## Member Typedef Documentation

template<typename T1 , typename T2 , int R, int C>

typedef Eigen::Matrix<typename common_type<T1, T2>::type, R, C> stan::math::common_type< Eigen::Matrix< T1, R, C >, Eigen::Matrix< T2, R, C > >::type

Definition at line 24 of file common_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/common_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.